@@ -15,7 +15,7 @@
 #ifndef vtk_lz4_h
 #define vtk_lz4_h
 
-/* #undef VTK_USE_SYSTEM_LZ4 */
+#define VTK_USE_SYSTEM_LZ4
 #ifdef VTK_USE_SYSTEM_LZ4
 # include <lz4.h>
 #else
