@@ -27,6 +27,8 @@
 #include <vtkm/Types.h>
 #include <vtkm/VecVariable.h>
 
+#include <vtkm/internal/Assume.h>
+
 namespace vtkm
 {
 namespace internal
@@ -40,7 +42,7 @@ template <>
 class ConnectivityStructuredInternals<1>
 {
 public:
-  typedef vtkm::Id SchedulingRangeType;
+  using SchedulingRangeType = vtkm::Id;
 
   VTKM_EXEC_CONT
   void SetPointDimensions(vtkm::Id dimensions) { this->PointDimensions = dimensions; }
@@ -63,8 +65,8 @@ public:
     return this->GetNumberOfPoints();
   }
 
-  static const vtkm::IdComponent NUM_POINTS_IN_CELL = 2;
-  static const vtkm::IdComponent MAX_CELL_TO_POINT = 2;
+  static constexpr vtkm::IdComponent NUM_POINTS_IN_CELL = 2;
+  static constexpr vtkm::IdComponent MAX_CELL_TO_POINT = 2;
 
   VTKM_EXEC_CONT
   vtkm::Id GetNumberOfPoints() const { return this->PointDimensions; }
@@ -75,11 +77,13 @@ public:
   VTKM_EXEC_CONT
   vtkm::IdComponent GetCellShape() const { return vtkm::CELL_SHAPE_LINE; }
 
-  typedef vtkm::CellShapeTagLine CellShapeTag;
+  using CellShapeTag = vtkm::CellShapeTagLine;
 
   VTKM_EXEC_CONT
   vtkm::Vec<vtkm::Id, NUM_POINTS_IN_CELL> GetPointsOfCell(vtkm::Id index) const
   {
+    VTKM_ASSUME(index >= 0);
+
     vtkm::Vec<vtkm::Id, NUM_POINTS_IN_CELL> pointIds;
     pointIds[0] = index;
     pointIds[1] = pointIds[0] + 1;
@@ -89,6 +93,8 @@ public:
   VTKM_EXEC_CONT
   vtkm::IdComponent GetNumberOfCellsOnPoint(vtkm::Id pointIndex) const
   {
+    VTKM_ASSUME(pointIndex >= 0);
+
     if ((pointIndex > 0) && (pointIndex < this->PointDimensions - 1))
     {
       return 2;
@@ -102,6 +108,9 @@ public:
   VTKM_EXEC_CONT
   vtkm::VecVariable<vtkm::Id, MAX_CELL_TO_POINT> GetCellsOfPoint(vtkm::Id index) const
   {
+    VTKM_ASSUME(index >= 0);
+    VTKM_ASSUME(this->PointDimensions > 1);
+
     vtkm::VecVariable<vtkm::Id, MAX_CELL_TO_POINT> cellIds;
 
     if (index > 0)
@@ -116,6 +125,7 @@ public:
     return cellIds;
   }
 
+
   VTKM_EXEC_CONT
   vtkm::Id FlatToLogicalPointIndex(vtkm::Id flatPointIndex) const { return flatPointIndex; }
 
@@ -145,7 +155,7 @@ template <>
 class ConnectivityStructuredInternals<2>
 {
 public:
-  typedef vtkm::Id2 SchedulingRangeType;
+  using SchedulingRangeType = vtkm::Id2;
 
   VTKM_EXEC_CONT
   void SetPointDimensions(vtkm::Id2 dims) { this->PointDimensions = dims; }
@@ -171,8 +181,8 @@ public:
     return this->GetPointDimensions();
   }
 
-  static const vtkm::IdComponent NUM_POINTS_IN_CELL = 4;
-  static const vtkm::IdComponent MAX_CELL_TO_POINT = 4;
+  static constexpr vtkm::IdComponent NUM_POINTS_IN_CELL = 4;
+  static constexpr vtkm::IdComponent MAX_CELL_TO_POINT = 4;
 
   VTKM_EXEC_CONT
   vtkm::Id GetNumberOfCells() const { return vtkm::ReduceProduct(this->GetCellDimensions()); }
@@ -181,7 +191,7 @@ public:
   VTKM_EXEC_CONT
   vtkm::IdComponent GetCellShape() const { return vtkm::CELL_SHAPE_QUAD; }
 
-  typedef vtkm::CellShapeTagQuad CellShapeTag;
+  using CellShapeTag = vtkm::CellShapeTagQuad;
 
   VTKM_EXEC_CONT
   vtkm::Vec<vtkm::Id, NUM_POINTS_IN_CELL> GetPointsOfCell(
@@ -303,7 +313,7 @@ template <>
 class ConnectivityStructuredInternals<3>
 {
 public:
-  typedef vtkm::Id3 SchedulingRangeType;
+  using SchedulingRangeType = vtkm::Id3;
 
   VTKM_EXEC_CONT
   void SetPointDimensions(vtkm::Id3 dims)
@@ -334,8 +344,8 @@ public:
     return this->GetPointDimensions();
   }
 
-  static const vtkm::IdComponent NUM_POINTS_IN_CELL = 8;
-  static const vtkm::IdComponent MAX_CELL_TO_POINT = 8;
+  static constexpr vtkm::IdComponent NUM_POINTS_IN_CELL = 8;
+  static constexpr vtkm::IdComponent MAX_CELL_TO_POINT = 8;
 
   VTKM_EXEC_CONT
   vtkm::Id GetNumberOfCells() const { return vtkm::ReduceProduct(this->GetCellDimensions()); }
@@ -344,7 +354,7 @@ public:
   VTKM_EXEC_CONT
   vtkm::IdComponent GetCellShape() const { return vtkm::CELL_SHAPE_HEXAHEDRON; }
 
-  typedef vtkm::CellShapeTagHexahedron CellShapeTag;
+  using CellShapeTag = vtkm::CellShapeTagHexahedron;
 
   VTKM_EXEC_CONT
   vtkm::Vec<vtkm::Id, NUM_POINTS_IN_CELL> GetPointsOfCell(const SchedulingRangeType& ijk) const
@@ -512,12 +522,12 @@ struct ConnectivityStructuredIndexHelper<vtkm::TopologyElementTagPoint,
                                          vtkm::TopologyElementTagCell,
                                          Dimension>
 {
-  typedef vtkm::internal::ConnectivityStructuredInternals<Dimension> ConnectivityType;
-  typedef typename ConnectivityType::SchedulingRangeType LogicalIndexType;
+  using ConnectivityType = vtkm::internal::ConnectivityStructuredInternals<Dimension>;
+  using LogicalIndexType = typename ConnectivityType::SchedulingRangeType;
 
   using CellShapeTag = typename ConnectivityType::CellShapeTag;
 
-  typedef vtkm::Vec<vtkm::Id, ConnectivityType::NUM_POINTS_IN_CELL> IndicesType;
+  using IndicesType = vtkm::Vec<vtkm::Id, ConnectivityType::NUM_POINTS_IN_CELL>;
 
   VTKM_EXEC_CONT static vtkm::Id GetNumberOfElements(const ConnectivityType& connectivity)
   {
@@ -573,12 +583,12 @@ struct ConnectivityStructuredIndexHelper<vtkm::TopologyElementTagCell,
                                          vtkm::TopologyElementTagPoint,
                                          Dimension>
 {
-  typedef vtkm::internal::ConnectivityStructuredInternals<Dimension> ConnectivityType;
-  typedef typename ConnectivityType::SchedulingRangeType LogicalIndexType;
+  using ConnectivityType = vtkm::internal::ConnectivityStructuredInternals<Dimension>;
+  using LogicalIndexType = typename ConnectivityType::SchedulingRangeType;
 
   using CellShapeTag = vtkm::CellShapeTagVertex;
 
-  typedef vtkm::VecVariable<vtkm::Id, ConnectivityType::MAX_CELL_TO_POINT> IndicesType;
+  using IndicesType = vtkm::VecVariable<vtkm::Id, ConnectivityType::MAX_CELL_TO_POINT>;
 
   VTKM_EXEC_CONT static vtkm::Id GetNumberOfElements(const ConnectivityType& connectivity)
   {
