@@ -91,69 +91,81 @@ public class vtkOpenGLPolyDataMapper extends vtkPolyDataMapper
   public void ClearShaderReplacement(int id0,String id1,boolean id2)
     { ClearShaderReplacement_20(id0,id1,id2); }
 
-  private native void SetVertexShaderCode_21(String id0);
+  private native void ClearAllShaderReplacements_21(int id0);
+  public void ClearAllShaderReplacements(int id0)
+    { ClearAllShaderReplacements_21(id0); }
+
+  private native void ClearAllShaderReplacements_22();
+  public void ClearAllShaderReplacements()
+    { ClearAllShaderReplacements_22(); }
+
+  private native void SetVertexShaderCode_23(String id0);
   public void SetVertexShaderCode(String id0)
-    { SetVertexShaderCode_21(id0); }
+    { SetVertexShaderCode_23(id0); }
 
-  private native String GetVertexShaderCode_22();
+  private native String GetVertexShaderCode_24();
   public String GetVertexShaderCode()
-    { return GetVertexShaderCode_22(); }
+    { return GetVertexShaderCode_24(); }
 
-  private native void SetFragmentShaderCode_23(String id0);
+  private native void SetFragmentShaderCode_25(String id0);
   public void SetFragmentShaderCode(String id0)
-    { SetFragmentShaderCode_23(id0); }
+    { SetFragmentShaderCode_25(id0); }
 
-  private native String GetFragmentShaderCode_24();
+  private native String GetFragmentShaderCode_26();
   public String GetFragmentShaderCode()
-    { return GetFragmentShaderCode_24(); }
+    { return GetFragmentShaderCode_26(); }
 
-  private native void SetGeometryShaderCode_25(String id0);
+  private native void SetGeometryShaderCode_27(String id0);
   public void SetGeometryShaderCode(String id0)
-    { SetGeometryShaderCode_25(id0); }
+    { SetGeometryShaderCode_27(id0); }
 
-  private native String GetGeometryShaderCode_26();
+  private native String GetGeometryShaderCode_28();
   public String GetGeometryShaderCode()
-    { return GetGeometryShaderCode_26(); }
+    { return GetGeometryShaderCode_28(); }
 
-  private native void ShallowCopy_27(vtkAbstractMapper id0);
+  private native void ShallowCopy_29(vtkAbstractMapper id0);
   public void ShallowCopy(vtkAbstractMapper id0)
-    { ShallowCopy_27(id0); }
+    { ShallowCopy_29(id0); }
 
-  private native void ForceHaveAppleBugOff_28();
+  private native void ForceHaveAppleBugOff_30();
   public void ForceHaveAppleBugOff()
-    { ForceHaveAppleBugOff_28(); }
+    { ForceHaveAppleBugOff_30(); }
 
-  private native void ForceHaveAppleBugOn_29();
+  private native void ForceHaveAppleBugOn_31();
   public void ForceHaveAppleBugOn()
-    { ForceHaveAppleBugOn_29(); }
+    { ForceHaveAppleBugOn_31(); }
 
-  private native boolean GetHaveAppleBug_30();
+  private native boolean GetHaveAppleBug_32();
   public boolean GetHaveAppleBug()
-    { return GetHaveAppleBug_30(); }
+    { return GetHaveAppleBug_32(); }
 
-  private native long GetVBOs_31();
+  private native long GetVBOs_33();
   public vtkOpenGLVertexBufferObjectGroup GetVBOs() {
-    long temp = GetVBOs_31();
+    long temp = GetVBOs_33();
 
     if (temp == 0) return null;
     return (vtkOpenGLVertexBufferObjectGroup)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native void SetVBOShiftScaleMethod_32(int id0);
+  private native void SetVBOShiftScaleMethod_34(int id0);
   public void SetVBOShiftScaleMethod(int id0)
-    { SetVBOShiftScaleMethod_32(id0); }
+    { SetVBOShiftScaleMethod_34(id0); }
 
-  private native void MapDataArrayToVertexAttribute_33(String id0,String id1,int id2,int id3);
+  private native void MapDataArrayToVertexAttribute_35(String id0,String id1,int id2,int id3);
   public void MapDataArrayToVertexAttribute(String id0,String id1,int id2,int id3)
-    { MapDataArrayToVertexAttribute_33(id0,id1,id2,id3); }
+    { MapDataArrayToVertexAttribute_35(id0,id1,id2,id3); }
 
-  private native void RemoveVertexAttributeMapping_34(String id0);
+  private native void MapDataArrayToMultiTextureAttribute_36(String id0,String id1,int id2,int id3);
+  public void MapDataArrayToMultiTextureAttribute(String id0,String id1,int id2,int id3)
+    { MapDataArrayToMultiTextureAttribute_36(id0,id1,id2,id3); }
+
+  private native void RemoveVertexAttributeMapping_37(String id0);
   public void RemoveVertexAttributeMapping(String id0)
-    { RemoveVertexAttributeMapping_34(id0); }
+    { RemoveVertexAttributeMapping_37(id0); }
 
-  private native void RemoveAllVertexAttributeMappings_35();
+  private native void RemoveAllVertexAttributeMappings_38();
   public void RemoveAllVertexAttributeMappings()
-    { RemoveAllVertexAttributeMappings_35(); }
+    { RemoveAllVertexAttributeMappings_38(); }
 
   public vtkOpenGLPolyDataMapper() { super(); }
 
