@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkUnstructuredGridReader extends vtkDataReader
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -21,7 +21,7 @@ public class vtkUnstructuredGridReader extends vtkDataReader
 
     if (temp == 0) return null;
     return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetOutput_3(int id0);
   public vtkUnstructuredGrid GetOutput(int id0) {
@@ -29,12 +29,16 @@ public class vtkUnstructuredGridReader extends vtkDataReader
 
     if (temp == 0) return null;
     return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void SetOutput_4(vtkUnstructuredGrid id0);
   public void SetOutput(vtkUnstructuredGrid id0)
     { SetOutput_4(id0); }
 
+  private native int ReadMeshSimple_5(String id0,vtkDataObject id1);
+  public int ReadMeshSimple(String id0,vtkDataObject id1)
+    { return ReadMeshSimple_5(id0,id1); }
+
   public vtkUnstructuredGridReader() { super(); }
 
   public vtkUnstructuredGridReader(long id) { super(id); }
